function [result] = solver_Poincare_sections_BV(seed,R,gamma,a,iteration,t_fixed,t_trans)
% solver_Poincare_sections_BV.m creates Poincare sections
% seed: initial particle positions
% R: radius of (domain) circle
% gamma: vortex strength
% iteration: the number of iterations
% a: fixed vortex centre
% t_fixed: time spent on stationary state
% t_trans: time spent on transition

tic

    function dydt = movingVortex(t,y)
        % moving vortex centre
        a_t = ((-1)^(i+1))*a*(1-2*t/(t_trans/2));
        
        % time integration scheme
        dydt = zeros(2,1);
        dydt(1) = -gamma/(2*pi)*(y(2)/((y(1)-a_t)^2+y(2)^2)-y(2)/((y(1)-R^2/a_t)^2+y(2)^2));
        dydt(2) = gamma/(2*pi)*((y(1)-a_t)/((y(1)-a_t)^2+y(2)^2)-(y(1)-R^2/a_t)/((y(1)-R^2/a_t)^2+y(2)^2));
    end

tspan=[1e-4 t_trans/2];
options = odeset('AbsTol',1e-7,'RelTol',1e-4);

% seed particles
zeta=seed;
N_particle=length(zeta); % the number of particles

% Initialise particle position storage
storeValues=zeros(iteration,N_particle);
storeValues(1,:)=seed;
ind=2; % index for storeValues

% Initialise temporary particle position storage
saveValues=zeros(1,N_particle);
x_t = zeros(1,length(N_particle));
y_t = zeros(1,length(N_particle));

for i=1:2*iteration
    %%%%%%%%%%%%%%%%%%%%%%%%%%%% Aref's mapping %%%%%%%%%%%%%%%%%%%%%%%%%%%
    if mod(i,2)==0
        zeta=-zeta;
    end

    lambda=abs((zeta-a)./(zeta-R^2/a));
    rho=(lambda./(1-lambda.^2))*(R^2/a-a);
    zeta_c=(a-(lambda*R).^2/a)./(1-lambda.^2);
    
    phi=real(-1i*log((zeta-zeta_c)./rho));
    
    A=phi-2*lambda.*sin(phi)./(1+lambda.^2)+gamma*t_fixed*(1-lambda.^2)./(4*pi()*rho.^2.*(1+lambda.^2));
    
    for n=1:N_particle
        func=@(x) x-2*lambda(n).*sin(x)./(1+lambda(n).^2)-A(n);
        phi(n)=fzero(func,phi(n));
    end

    zeta=zeta_c+rho.*exp(1i*phi);
    
    if mod(i,2)==0
        zeta=-zeta;
    end
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%% transition %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%  
    % prticle position
    x0_t = real(zeta);
    y0_t = imag(zeta);
    
    ind2=1; % index for saveValues
    for m=1:N_particle
        % initial conditions
        X0_t = [x0_t(m),y0_t(m)];

        % time integration scheme
        [t,X]=ode45(@movingVortex,tspan,X0_t,options);
        
        % store positions after transition
        x_t(m) = X(end,1);
        y_t(m) = X(end,2);
        
        if mod(i,2)==0
            saveValues(ind2)=X(end,1)+1i*X(end,2);
            ind2=ind2+1;
        end
    end

    if mod(i,2)==0
        storeValues(ind,:)=saveValues;
        ind=ind+1;
    end
    
    % return to complex number
    zeta=x_t+1i*y_t;  
end

result=storeValues;

toc

beep
end